@@ -11,47 +11,43 @@
 ################################
 FairCrpsDiff <- function(ens, ens.ref, obs, probs=NA) {
 
-  # sanity checks
-  if (class(ens) == "data.frame") {
-    ens <- as.matrix(ens)
-  }
-  if (class(ens.ref) == "data.frame") {
-    ens.ref <- as.matrix(ens.ref)
-  }
-  if (class(obs) == "data.frame") {
-    obs <- c(as.matrix(obs))
-  }
-  stopifnot(is.numeric(c(ens, ens.ref, obs)))
-  stopifnot(is.vector(obs), length(obs) > 1)
-  stopifnot(is.matrix(ens), is.matrix(ens.ref))
-  stopifnot(nrow(ens)==length(obs), nrow(ens.ref) == length(obs))
+
+  # pre-processing
+  l <- Preprocess(ens=ens, ens.ref=ens.ref, obs=obs)
+  ens <- l[["ens"]]
+  ens.ref <- l[["ens.ref"]]
+  obs <- l[["obs"]]
 
   N <- length(obs)
-  K <- ncol(ens)
-  K.ref <- ncol(ens.ref)
-  obs <- matrix(obs, ncol=1)
-
-  K <- ncol(ens)
-  K.ref <- ncol(ens.ref)
 
   # calculate fair crps difference
   crps.ens <- FairCrps(ens, obs)
   crps.ref <- FairCrps(ens.ref, obs)
   crps.diff <- crps.ref - crps.ens
-  mean.crps.diff <- mean(crps.diff)
+  mean.crps.diff <- mean(crps.diff, na.rm=TRUE)
+  sd.crps.diff <- sd(crps.diff, na.rm=TRUE)
 
+  # update N, accounting for NA's
+  N <- N - sum(is.na(crps.diff))
+
+  # if all scores are NA, return NA
+  if (all(is.na(crps.diff))) {
+    return(list(crps.diff=NA, sampling.quantiles=probs*NA, p.value=NA))
+  }
 
   # quantiles of the sampling distribution 
   cis <- NA
-  if (!any(is.na(probs))) {
+  if (!any(is.na(probs)) && N > 1) {
     stopifnot(all(probs > 0 & probs < 1))
     probs <- sort(probs)
-    cis <- qt(probs, df=N-1) * sd(crps.diff) / sqrt(N) + mean.crps.diff
+    cis <- qt(probs, df=N-1) * sd.crps.diff / sqrt(N) + mean.crps.diff
     names(cis) <- paste(probs)
   }
 
   # p value of paired one-sided t test for positive score difference
-  p.value <- 1-pt(mean.crps.diff / sd(crps.diff) * sqrt(N), df=N-1)
+  p.value <- ifelse(N>1, 
+    1-pt(mean.crps.diff / sd.crps.diff * sqrt(N), df=N-1), 
+    NA)
 
   #return
   list(crps.diff=mean.crps.diff, sampling.quantiles=cis, p.value=p.value)
